@@ -33,7 +33,7 @@ const { LambdaToDynamoDBProps,  LambdaToDynamoDB } = require('@aws-solutions-con
 
 const props: LambdaToDynamoDBProps = {
     lambdaFunctionProps: {
-        code: lambda.Code.asset(`${__dirname}/lambda`),
+        code: lambda.Code.fromAsset(`${__dirname}/lambda`),
         runtime: lambda.Runtime.NODEJS_12_X,
         handler: 'index.handler'
     },
